@@ -79,7 +79,7 @@ sub new($;$$$) {
     # Set in 'watch' command, and reset here after we get the value back.
     $self->{set_wp}         = undef;
 
-    $self->{step_count}     = 0;
+    $self->{skip_count}     = 0;
     $self->load_cmds_initialize;
     $self->running_initialize;
     $self->hook_initialize;
@@ -265,7 +265,7 @@ sub process_after_eval($) {
             }
             $self->msg("$prefix\n\@\{$val_str}");
     } elsif ('>' eq $return_type || '2>' eq $return_type ) {
-	$self->msg($DB::eval_result);
+        $self->msg($DB::eval_result);
     }  else {
             if (defined $DB::eval_result) {
                 if ('dprint' eq $evdisp) {
@@ -348,17 +348,30 @@ sub process_commands($$$;$)
 
         $next_skip = skip_if_next($self, $event);
         unless ($next_skip) { 
+
+            # prehooks include traceprint, list, and event saving.
             $self->{unconditional_prehooks}->run;
+
             if (index($self->{event}, 'brkpt') < 0 && !$self->{terminated}) {
                 # Not a breakpoint and not terminated.
-                if ($self->is_stepping_skip()) {
-                    # || $self->{stack_size} <= $self->{hide_level};
-                    $self->{dbgr}->step;
-                    return;
-                }
-                if ($self->{settings}{traceprint}) {
-                    $self->{dbgr}->step;
-                    return;
+
+                if ($event eq 'line') {
+
+                    # We may want to not stop because of "step n"; step different, or 
+                    # "next"
+                    # use Enbugger; Enbugger->stop if 2 == $self->{next_level};
+                    if ($self->is_stepping_skip()) {
+                        # || $self->{stack_size} <= $self->{hide_level};
+                        $self->{dbgr}->step;
+                        return;
+                    }
+                    # trace print sets stepping even when though otherwise
+                    # we may be are continuing, nexting, finishing, or
+                    # returning.
+                    if ($self->{settings}{traceprint}) {
+                        $self->{dbgr}->step;
+                        return unless 0 == $self->{skip_count};
+                    }
                 }
             }
         
@@ -391,9 +404,9 @@ sub process_commands($$$;$)
         }
     }
     unless ($self->{terminated}) {
-	$self->{cmdloop_posthooks}->run;
-	$self->{last_tid} = $DB::tid;
-	$DB::single       = $self->{DB_single};
+        $self->{cmdloop_posthooks}->run;
+        $self->{last_tid} = $DB::tid;
+        $DB::single       = $self->{DB_single};
     }
     $DB::running      = $self->{DB_running};
 
@@ -426,18 +439,28 @@ sub run_command($$)
             return if scalar(@args) == 0;
             my $macro_cmd_name = $args[0];
             last unless $self->{macros}{$macro_cmd_name};
-            pop @args;
+	    my $debugging = $self->{settings}{debugmacro};
+	    # if ($debugging) {
+	    # 	require Enbugger; Enbugger->stop();
+	    # }
+            shift @args;
             my $macro_expanded = 
                 $self->{macros}{$macro_cmd_name}[0]->(@args);
-#           $self->msg($macro_expanded) if $self->{settings}{debugmacro};
             if (ref $macro_expanded eq 'ARRAY' #  && 
 #               current_command.all? {|val| val.is_a?(String)}
                 ) {
                 my @new_commands = @{$macro_expanded};
-                push @cmd_queue, @new_commands;
-                $current_command = shift @cmd_queue;
-                @args = split(' ', $current_command);
+		$self->msg(join(' ', @new_commands)) if $debugging;
+		if (scalar @new_commands > 0) {
+		    push @cmd_queue, @new_commands;
+		    $current_command = shift @cmd_queue;
+		    @args = split(' ', $current_command);
+		} else {
+		    $current_command = '#';
+		    @args = ();
+		}
             } else {
+		$self->msg($macro_expanded) if $debugging;
                 $current_command = $macro_expanded;
                 @args = split(/\s+/, $current_command);
             # } else {
