@@ -55,11 +55,11 @@ If no sub-options are given, \"$DEFAULT_FILE_ARGS\" are assumed.
 
 Examples:
 
-${CMD}    # Show \"${DEFAULT_FILE_ARGS}\" information about current file
-${CMD} .  # same as above
-${CMD} brkpts      # show the number of lines in the current file
-${CMD} brkpts size # same as above but also list breakpoint line numbers
-${CMD} *  # Give a list of files we know about
+${CMD}      # Show \"${DEFAULT_FILE_ARGS}\" information about current file
+${CMD} .    # same as above
+${CMD} . brkpts      # show the number of lines in the current file
+${CMD} . brkpts size # same as above but also list breakpoint line numbers
+${CMD} *    # Give a list of files we know about
 HELP
 
 our $SHORT_HELP = 'Show information about the current loaded file(s)';
@@ -164,6 +164,7 @@ sub run($$)
 	    	$proc->msg("Possible breakpoint line numbers:");
 	    	my @lines = DB::LineCache::trace_line_numbers($canonic_name);
 	    	my $fmt_lines = $self->{cmd}->columnize_numbers(\@lines);
+		chomp $fmt_lines;
 	    	$proc->msg($fmt_lines);
 	    }
 	    $processed_arg = $seen{brkpts} = 1;
